==> Paws-0.43.tar.gz: Paws-0.43/lib/Paws/SMS/DeleteReplicationJob.pm <==

package Paws::SMS::DeleteReplicationJob;
  use Moose;
  has ReplicationJobId => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'replicationJobId' , required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DeleteReplicationJob');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::SMS::DeleteReplicationJobResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::SMS::DeleteReplicationJob - Arguments for method DeleteReplicationJob on L<Paws::SMS>

=head1 DESCRIPTION

This class represents the parameters used for calling the method DeleteReplicationJob on the
L<AWS Server Migration Service|Paws::SMS> service. Use the attributes of this class
as arguments to method DeleteReplicationJob.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DeleteReplicationJob.

=head1 SYNOPSIS

    my $sms = Paws->service('SMS');
    my $DeleteReplicationJobResponse = $sms->DeleteReplicationJob(
      ReplicationJobId => 'MyReplicationJobId',

    );

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/sms/DeleteReplicationJob>

=head1 ATTRIBUTES


=head2 B<REQUIRED> ReplicationJobId => Str

The identifier of the replication job.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DeleteReplicationJob in L<Paws::SMS>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

==> Paws-0.46.tar.gz: Paws-0.46/lib/Paws/SMS/DeleteReplicationJob.pm <==

package Paws::SMS::DeleteReplicationJob;
  use Moose;
  has ReplicationJobId => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'replicationJobId' , required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DeleteReplicationJob');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::SMS::DeleteReplicationJobResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::SMS::DeleteReplicationJob - Arguments for method DeleteReplicationJob on L<Paws::SMS>

=head1 DESCRIPTION

This class represents the parameters used for calling the method DeleteReplicationJob on the
L<AWS Server Migration Service|Paws::SMS> service. Use the attributes of this class
as arguments to method DeleteReplicationJob.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DeleteReplicationJob.

=head1 SYNOPSIS

    my $sms = Paws->service('SMS');
    my $DeleteReplicationJobResponse = $sms->DeleteReplicationJob(
      ReplicationJobId => 'MyReplicationJobId',

    );

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/sms/DeleteReplicationJob>

=head1 ATTRIBUTES


=head2 B<REQUIRED> ReplicationJobId => Str

The ID of the replication job.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DeleteReplicationJob in L<Paws::SMS>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
